/* do-file for North American Stata Users Group Meeting,
   Boston, MA, 2003
   
   Sophia Rabe-Hesketh
*/


******** Myocardial Infarction ***************************
insheet using mi.dat, clear
rename q y1
rename h y2
rename l y3
rename c y4
gen wt2 = count
gen patt=_n

reshape long y, i(patt) j(var)
tab var, gen(v)

eq v1: v1
eq v2: v2
eq v3: v3
eq v4: v4

gllamm y, i(patt) ip(fn) nip(2)  eqs(v1 v2 v3 v4) /*
  */ weight(wt) nrf(4) l(logit) f(binom) nocons 

  
*** conditional response probabilities

* sensitivity
gen e1 = 1.1903 
gen e2 = 1.3333
gen e3 = 1.5708
gen e4 = 16.857

gllapred cprob, mu us(e) 

* specificity
gen d1 = -17.585
gen d2 = -1.4173
gen d3 = -3.5875
gen d4 = -1.4143

gllapred junk, mu us(d) 
gen spec = 1-junk

* (Note: slide 11 gives 1-Spec and has a mistake for [History]

*** posterior probabilities

* to get predictions where wt2=0, change wt2
replace wt2 = 1
gllapred prob, p

*** predicted counts

gllapred l, ll
gen ecount = 94*exp(l)

*** reshape data to get slode 13

keep patt var y prob2 count ecount
reshape wide y , i(patt) j(var)

gsort -y4 -y3 -y2 -y1

list y1-y4 count ecount prob2, clean noobs


*************** Attitudes to Abortion **********************

use attitudes, clear

list id cou-rap fem area83 pwt2 in 1/8, clean noobs

*** Discrete 1-factor model (Model 1)

eq fac: wom cou mar fin gen ris rap

gllamm ab wom cou mar fin gen ris rap, nocons i(id)/*
*/ nrf(1) l(logit) f(binom) eqs(fac) ip(f) nip(2)

*** Discrete one-factor model where latent class prob.
  * depends on sex (Model 2)
  
matrix a = e(b)
eq fem: fem

gllamm ab wom cou mar fin gen ris rap, nocons i(id)/*
*/ nrf(1) l(logit) f(binom) eqs(fac) peqs(fem) /*
*/ ip(f) nip(2) from(a)

* -- typos for first 2 coeffs, slides 17 and 21
estimates store model2


*** Model as above with additional direct effect of female
   * on second item

gen femcou = fem*cou
gllamm ab wom cou femcou mar fin gen ris rap, nocons i(id)/*
*/ nrf(1) l(logit) f(binom) eqs(fac) peqs(fem) /*
*/ ip(f) nip(2)

*** Model 3 (same as Model 1 but with 3 classes)
eq fac: wom cou mar fin gen ris rap

gllamm ab wom cou mar fin gen ris rap, nocons i(id)/*
*/ nrf(1) l(logit) f(binom) eqs(fac) ip(f) nip(3)

*** Model 4 (same as Model 2 but with 3 classes)

matrix a=e(b)
eq fem: fem

gllamm ab wom cou mar fin gen ris rap, nocons i(id)/*
*/ nrf(1) l(logit) f(binom) eqs(fac) peqs(fem) /*
*/ ip(f) nip(3) from(a)

*** conditional probabilities for classes 1 to 3
  * will be in id=1,2,3

gen e1 = -8.9023 if id==1
replace e1 = 1.9589 if id==2
replace e1 = -.85985 if id==3

gllapred mup, mu us(e)

sort id sit
list id sit mup if id<=3, sepby(id) clean

*** marginal proabilities

gllapred mu, mu marg
table sit fem, contents(mean mu)

**** Complex survey data (Model 2) 
estimates restore model2

matrix a = e(b)
eq fem: fem

gllamm ab wom cou mar fin gen ris rap, nocons i(id)/*
*/ nrf(1) l(logit) f(binom) eqs(fac) peqs(fem) /*
*/ ip(f) nip(2) from(a) pweight(pwt)

gllamm, cluster(area83)
